# insider-scraper
A simple CLI app for scraping events from insider.in
# Installation
## Using Pip
```bash
  $ pip install insider-scraper
```
## Manual
```bash
  $ git clone https://github.com/MinatoNamikaze02/insider-scraper
  $ cd insider-scraper
  $ python setup.py install
```
# Usage
## Help
```bash
  $ insider-scraper --help
```
## Extract Events
```bash
  $ insider-scraper --city chennai --browser safari --driver-path '' --download-folder downloads
  $ insider-scraper -c chennai -b safari -dp '' -df downloads
```
# Bugs?
Feel free to open an issue.